@@ -35,7 +35,7 @@ tkadd(priceMenu, "command", label="Time series plot", command =.pricePlot)
 tkadd(priceMenu, "command", label="ACF/PACF plot", command =.PriceAcfPlots)
 tkadd(priceMenu, "command", label="Box plot", command =.PriceBoxPlots)
 tkadd(priceMenu, "command", label="Technical charting(For OHLC only)", command =.priceCharting)
-tkadd(priceMenu, "command", label="iClick Visualization", command =.iClickPrice)
+tkadd(priceMenu, "command", label="Advanced Visualization", command =.iClickPrice_Menu)
 
 #3. Returns
 returnsMenu <- tkmenu(menuBar)
@@ -59,14 +59,12 @@ tkadd(returnsMenu, "command", label="Dependency plots", command =.acfPlots)
 tkadd(returnsMenu, "command", label="Four QQ plots", command =.QQPlot)
 tkadd(returnsMenu, "command", label="NIG triangle", command =.nigTriangle)
 tkadd(returnsMenu, "command", label="Box plot", command =.ReturnsBoxPlots)
-tkadd(returnsMenu, "command", label="iClick Visualization", command =.iClickReturn)
-tkadd(returnsMenu, "command", label="GARCH", command =.garchMenu)
-
+tkadd(returnsMenu, "command", label="Advanced Visualization", command =.iClickReturn)
 
 #4. Assets selections
 assetSelectionMenu <- tkmenu(menuBar)
 tkadd(menuBar,"cascade",label="Assets Selection", menu=assetSelectionMenu)
-tkadd(assetSelectionMenu,"command", label = "Read Me",command = .readme4Selection)
+#tkadd(assetSelectionMenu,"command", label = "Read Me",command = .readme4Selection)
 tkadd(assetSelectionMenu, "command", label="Transform Price Data",command = function() {
         dir_name <- tkchooseDirectory()
         if(nchar(dir_name <- as.character(dir_name)))
@@ -84,7 +82,7 @@ tkadd(assetSelectionMenu, "command", label= "Assets Selection by Performance Ind
 #5.Backtesting
 backtestMenu <- tkmenu(menuBar)
 tkadd(menuBar,"cascade",label="Portfolio Backtesting", menu=backtestMenu)
-tkadd(backtestMenu,"command", label = "Read Me",command = .readme4backtesting)
+#tkadd(backtestMenu,"command", label = "Read Me",command = .readme4backtesting)
 tkadd(backtestMenu, "command", label="Transform Price Data",command = function() {
   dir_name <- tkchooseDirectory()
   if(nchar(dir_name <- as.character(dir_name)))
@@ -101,7 +99,7 @@ tkadd(backtestMenu,"command", label = "Change dataset in this Dir",command = .ge
 
 tkadd(backtestMenu, "command", label= "Backtesting", command =.backtestingMenu)
 
-tkadd(backtestMenu, "command", label= "iClick All-in-One", command =.iClickBacktesting_Menu)
+tkadd(backtestMenu, "command", label= "Backtesting All in One", command =.iClickBacktesting_Menu)
 
 # 6. High Frequency
 HFMenu <- tkmenu(menuBar)
@@ -120,15 +118,15 @@ tkadd(HFMenu,"command", label = "Transform Price Data",command = function() {
 #tkadd(performanceMenu, "command", label="Performance index", command =.performanceIndexMenu)
 
 
-#7. Big Data
-BDMenu <- tkmenu(menuBar)
-tkadd(menuBar,"cascade",label="bigData", menu=BDMenu)
-tkadd(BDMenu,"command", label = "Load Raw data",command = function() {
+#7. Predictive Modelling
+PMMenu <- tkmenu(menuBar)
+tkadd(menuBar,"cascade",label="PredictiveModelling", menu=PMMenu)
+tkadd(PMMenu,"command", label = "Load Raw data",command = function() {
         dir_name <- tkchooseDirectory()
         if(nchar(dir_name <- as.character(dir_name)))
      setwd(dir_name)
      .getRawData()})
-tkadd(BDMenu,"command", label = "Transform Price Data",command = function() {
+tkadd(PMMenu,"command", label = "Transform Price Data",command = function() {
         dir_name <- tkchooseDirectory()
         if(nchar(dir_name <- as.character(dir_name)))
      setwd(dir_name)
